@@ -227,6 +227,7 @@ after the table.
 
 """
 
+from copy import copy, deepcopy
 from datetime import date, datetime, time
 import re
 
@@ -321,6 +322,13 @@ class CoreType(dict):
 
         self.__dict__ = self
 
+    def __copy__(self):
+        return type(self)(copy(dict(self)))
+
+    def __deepcopy__(self, memo):
+        the_copy = dict(self.__dict__)
+        return type(self)(deepcopy(the_copy, memo))
+
 
 class MetaType(CoreType):
     r"""Interface for type definition of **Ontic** schema defined classes.
